==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>Up</source>
        <translation>Livello superiore</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="180"/>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <location filename="../qmmpfiledialog.ui" line="212"/>
        <location filename="../qmmpfiledialog.ui" line="237"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="190"/>
        <source>List view</source>
        <translation>Vista a elenco</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="209"/>
        <source>Detailed view</source>
        <translation>Vista dettagliata</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="234"/>
        <source>Close dialog on add</source>
        <translation>Chiudi finestra quando aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="106"/>
        <source>File name:</source>
        <translation>Nome file:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="122"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="129"/>
        <source>Files of type:</source>
        <translation>File di tipo:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="155"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="69"/>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Qmmp File Dialog</source>
        <translation>Finestra di dialogo Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>About Qmmp File Dialog</source>
        <translation>Informazioni sulla finestra di dialogo Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="83"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Parti del codice sono riprese dalla libreria Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="262"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="275"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="289"/>
        <source>Directories</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="476"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 esiste già.
Vuoi sostituirlo?</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="198"/>
        <source>Up</source>
        <translation>Livello superiore</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="201"/>
        <location filename="../qmmpfiledialog.ui" line="214"/>
        <location filename="../qmmpfiledialog.ui" line="233"/>
        <location filename="../qmmpfiledialog.ui" line="258"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="211"/>
        <source>List view</source>
        <translation>Vista a elenco</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="230"/>
        <source>Detailed view</source>
        <translation>Vista dettagliata</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="255"/>
        <source>Close dialog on add</source>
        <translation>Chiudi finestra quando aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="124"/>
        <source>File name:</source>
        <translation>Nome file:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="140"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="147"/>
        <source>Files of type:</source>
        <translation>Tipo brani:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="173"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="70"/>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Qmmp File Dialog</source>
        <translation>Finestra di dialogo Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>About Qmmp File Dialog</source>
        <translation>Informazioni sulla finestra di dialogo Qmmp</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="81"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="84"/>
        <source>Some code is copied from the Qt library</source>
        <translation>Parti del codice sono riprese dalla libreria Qt</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="251"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="264"/>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="278"/>
        <source>Directories</source>
        <translation>Cartelle</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="465"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 esiste già. Vuoi sostituirlo?</translation>
    </message>
</context>
</TS>
